@@ -6,7 +6,7 @@ import os
 
 def readFile(path):
     if os.path.exists(path):
-        with open(filename, "r") as f:
+        with open(path, "r") as f:
             content = f.readlines()
             f.close()
             return content
@@ -16,7 +16,7 @@ def readFile(path):
 
 def writeFile(path, inputString):
     try:
-        with open(filename, "w") as f:
+        with open(path, "w") as f:
             content = f.readlines()
             f.write(inputString)
             return content
@@ -26,7 +26,7 @@ def writeFile(path, inputString):
 
 def appendFile(path, inputString):
     try:
-        with open(filename, "a") as f:
+        with open(path, "a") as f:
             content = f.readlines()
             f.write(inputString)
             return content
